@@ -3,7 +3,7 @@
 #' The function creates scaled residuals by simulating from the fitted model. Residuals can be extracted with \code{\link{residuals.DHARMa}}. See \code{\link{testResiduals}} for an overview of residual tests, \code{\link{plot.DHARMa}} for an overview of available plots.
 #'
 #' @param fittedModel a fitted model  of a class supported by DHARMa
-#' @param n number of simulations. Default is 100. A more save value would be 250 or even 1000. The smaller the number, the higher the stochastic error on the residuals. Also, for very small n, discretization artefacts can influence the tests.
+#' @param n number of simulations. The smaller the number, the higher the stochastic error on the residuals. Also, for very small n, discretization artefacts can influence the tests. Default is 250, which is a relatively safe value. You can consider increasing to 1000 to stabilize the simulated values. 
 #' @param refit if FALSE, new data will be simulated and scaled residuals will be created by comparing observed data with new data. If TRUE, the model will be refit on the simulated data (parametric bootstrap), and scaled residuals will be created by comparing observed with refitted residuals.
 #' @param integerResponse if TRUE, noise will be added at to the residuals to maintain a uniform expectations for integer responses (such as Poisson or Binomial). Usually, the model will automatically detect the appropriate setting, so there is no need to adjust this setting.
 #' @param plot if TRUE, \code{\link{plotResiduals}} will be directly run after the residuals have been calculated
@@ -62,6 +62,7 @@ simulateResiduals <- function(fittedModel, n = 250, refit = F, integerResponse =
   out$nObs = nobs(fittedModel)
   out$nSim = n
   out$refit = refit
+  out$methods = method
   out$observedResponse = getObservedResponse(fittedModel)
 
   if(is.null(integerResponse)){
@@ -245,6 +246,9 @@ recalculateResiduals <- function(simulationOutput, group = NULL, aggregateBy = s
 
   out = list()
   out$original = simulationOutput
+  out$group = group
+  out$method = method
+  out$aggregateBy = aggregateBy
 
   if(is.null(group)) return(simulationOutput)
   else group =as.factor(group)
